models

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cipher

type Cipher interface {
	// KeyLen returns the length of the key used by the cipher.
	KeyLen() int

	// Encrypt encrypts the given plaintext using the cipher.
	Encrypt(plaintext []byte) ([]byte, error)
	// Decrypt decrypts the given ciphertext using the cipher.
	Decrypt(ciphertext []byte) ([]byte, error)
}

Cipher is the minimal interface that must be implemented by all ciphers.

Jump to